/*********************************************************************
* Mesh for MT experiment 9.3 described in:
* Zhu, X., Liu, J., Cui, Y., & Gong, C. (2020). An efficient parallel
* algorithm for 3D magnetotelluric modeling with edge-based finite
* element. Computational Geosciences, 1-16.
*
* Visit http://gmsh.info/ for details about mesh scripting with Gmsh
*
* by Octavio Castillo-Reyes, BSC-CASE (octavio.castillo@bsc.es)
* Latest update: June 3rd, 2021
*********************************************************************/
// #################################################################
// #                        Parameters                             #
// #################################################################
// Define box limits
xmin = -10000.;
xmax = 10000.;
ymin = -9000.;
ymax = 9000.;
zmax = 14000.;
zmin = -14000.;

// Define main points
Point (1) = {xmin, ymin, zmax};
Point (2) = {xmax, ymin, zmax};
Point (3) = {xmin, ymax, zmax};
Point (4) = {xmax, ymax, zmax};

Point (5) = {xmin, ymin, 0.};
Point (6) = {xmax, ymin, 0.};
Point (7) = {xmin, ymax, 0.};
Point (8) = {xmax, ymax, 0.};

Point (9) = {-1000., -1000., 0.};
Point (10) = {1000., -1000., 0.};
Point (11) = {-1000., 1000., 0.};
Point (12) = {1000., 1000., 0.};

Point (13) = {-225., -225., 450.};
Point (14) = {225., -225., 450.};
Point (15) = {-225., 225., 450.};
Point (16) = {225., 225., 450.};

Point (17) = {xmin, ymin, zmin};
Point (18) = {xmax, ymin, zmin};
Point (19) = {xmin, ymax, zmin};
Point (20) = {xmax, ymax, zmin};

// Define main lines
Line(1) = {1, 2};
Line(2) = {2, 4};
Line(3) = {4, 3};
Line(4) = {3, 1};
Line(5) = {1, 5};
Line(6) = {2, 6};
Line(7) = {4, 8};
Line(8) = {3, 7};
Line(9) = {7, 5};
Line(10) = {5, 6};
Line(11) = {6, 8};
Line(12) = {8, 7};
Line(13) = {11, 9};
Line(14) = {9, 10};
Line(15) = {12, 10};
Line(16) = {12, 11};
Line(17) = {13, 14};
Line(18) = {14, 16};
Line(19) = {16, 15};
Line(20) = {15, 13};
Line(21) = {9, 13};
Line(22) = {14, 10};
Line(23) = {16, 12};
Line(24) = {11, 15};
Line(25) = {5, 17};
Line(26) = {6, 18};
Line(27) = {8, 20};
Line(28) = {7, 19};
Line(29) = {17, 18};
Line(30) = {18, 20};
Line(31) = {20, 19};
Line(32) = {19, 17};
Curve Loop(1) = {1, 2, 3, 4};
Plane Surface(1) = {1};
Curve Loop(2) = {5, 10, -6, -1};
Plane Surface(2) = {2};
Curve Loop(3) = {2, 7, -11, -6};
Plane Surface(3) = {3};
Curve Loop(4) = {7, 12, -8, -3};
Plane Surface(4) = {4};
Curve Loop(5) = {8, 9, -5, -4};
Plane Surface(5) = {5};
Curve Loop(6) = {10, 11, 12, 9};
Curve Loop(7) = {13, 14, -15, 16};
Plane Surface(6) = {6, 7};
Curve Loop(8) = {21, 17, 22, -14};
Plane Surface(7) = {8};
Curve Loop(9) = {22, -15, -23, -18};
Plane Surface(8) = {9};
Curve Loop(10) = {19, -24, -16, -23};
Plane Surface(9) = {10};
Curve Loop(11) = {13, 21, -20, -24};
Plane Surface(10) = {11};
Curve Loop(12) = {20, 17, 18, 19};
Plane Surface(11) = {12};
Curve Loop(13) = {25, 29, -26, -10};
Plane Surface(12) = {13};
Curve Loop(14) = {26, 30, -27, -11};
Plane Surface(13) = {14};
Curve Loop(15) = {27, 31, -28, -12};
Plane Surface(14) = {15};
Curve Loop(16) = {9, 25, -32, -28};
Plane Surface(15) = {16};
Curve Loop(17) = {32, 29, 30, 31};
Plane Surface(16) = {17};

// Air
Surface Loop(1) = {1, 2, 5, 4, 3, 6, 9, 11, 10, 7, 8};
Volume(1) = {1};
Physical Volume ("air", 1) = {1};

// Sediments
Surface Loop(2) = {15, 12, 16, 13, 14, 6, 9, 11, 10, 7, 8};
Volume(2) = {2};
Physical Volume ("seds", 2) = {2};

// Add line of receivers
Point(100) = {-2000.,  0., -2.};
Point(101) = {-1900.,  0., -2.};
Point(102) = {-1800.,  0., -2.};
Point(103) = {-1700.,  0., -2.};
Point(104) = {-1600.,  0., -2.};
Point(105) = {-1500.,  0., -2.};
Point(106) = {-1400.,  0., -2.};
Point(107) = {-1300.,  0., -2.};
Point(108) = {-1200.,  0., -2.};
Point(109) = {-1100.,  0., -2.};
Point(110) = {-1000.,  0., -2.};
Point(111) = {-900.,  0.,  56.1};
Point(112) = {-800,  0.,  114.1};
Point(113) = {-700.,  0.,  172.2};
Point(114) = {-600.,  0.,  230.3};
Point(115) = {-500.,  0.,  288.3};
Point(116) = {-400.,  0.,  346.4};
Point(117) = {-300.,  0.,  404.5};
Point(118) = {-200.,  0.,  448.0};
Point(119) = {-100.,  0.,  448.0};
Point(120) = {      0.,  0.,  448.0};
Point(121) = { 100.,  0.,  448.0};
Point(122) = { 200.,  0.,  448.0};
Point(123) = { 300.,  0.,  404.5};
Point(124) = { 400.,  0.,  346.4};
Point(125) = { 500.,  0.,  288.3};
Point(126) = { 600.,  0.,  230.3};
Point(127) = { 700.,  0.,  172.2};
Point(128) = { 800.,  0.,  114.1};
Point(129) = { 900.,  0.,  56.1};
Point(130) = { 1000.,  0., -2.};
Point(131) = { 1100.,  0., -2.};
Point(132) = { 1200.,  0., -2.};
Point(133) = { 1300.,  0., -2.};
Point(134) = { 1400.,  0., -2.};
Point(135) = { 1500.,  0., -2.};
Point(136) = { 1600.,  0., -2.};
Point(137) = { 1700.,  0., -2.};
Point(138) = { 1800.,  0., -2.};
Point(139) = { 1900.,  0., -2.};
Point(140) = { 2000.,  0., -2.};
Point(141) = { -1900.,  0., -2.};
Point(142) = { 2100.,  0., -2.};

/*pList[0] = 100; // First point label
nPoints = 41; // Number of discretization points
xini = -2000.;   // initial x-coordinate

For i In {1 : nPoints}
  x = xini;
	pList[i] = newp;
	Point(pList[i]) = {x, 0., -2.};
  xini = xini + 100.;
EndFor
*/
// Refinement
/*Field[1] = Attractor;
Field[1].NodesList = {100:142};
Field[2] = MathEval;
Field[2].F = Sprintf("F1/3. + %g", 20.);
*/
Field[3] = Min;
Field[3].FieldsList = {2};
Background Field = 3;


// Mesh 1
Characteristic Length {1:4} = 1000.;
Characteristic Length {5:8} = 1000.;
Characteristic Length {9:16} = 1000.;
Characteristic Length {17:20} = 2000.;


/*// Mesh 1
Characteristic Length {1:4} = 180.;
Characteristic Length {5:8} = 260.;
Characteristic Length {9:16} = 100.;
Characteristic Length {17:20} = 410.;*/

// Mesh 2
/*Characteristic Length {1:4} = 160.;
Characteristic Length {5:8} = 240.;
Characteristic Length {9:16} = 90.;
Characteristic Length {17:20} = 390.;*/


// Mesh 3
/*Characteristic Length {1:4} = 140.;
Characteristic Length {5:8} = 220.;
Characteristic Length {9:16} = 80.;
Characteristic Length {17:20} = 370.;*/

// Mesh 4
/*Characteristic Length {1:4} = 120.;
Characteristic Length {5:8} = 200.;
Characteristic Length {9:16} = 70.;
Characteristic Length {17:20} = 350.;*/
// Mesh format supported by PETGEM
Mesh.MshFileVersion = 2.2;
